@@ -1,5 +1,5 @@
 """ Schema Tester """
-from functools import reduce
+from itertools import chain
 from typing import Any, Callable, Dict, List, Optional, Union, cast
 
 from django.conf import settings
@@ -19,7 +19,7 @@ from openapi_tester.constants import (
 )
 from openapi_tester.exceptions import DocumentationError, UndocumentedSchemaSectionError
 from openapi_tester.loaders import DrfSpectacularSchemaLoader, DrfYasgSchemaLoader, StaticSchemaLoader
-from openapi_tester.utils import combine_sub_schemas, merge_objects
+from openapi_tester.utils import lazy_combinations, normalize_schema_section
 from openapi_tester.validators import (
     validate_enum,
     validate_format,
@@ -152,15 +152,6 @@ class SchemaTester:
         )
         return self.get_key_value(json_object, "schema")
 
-    def handle_all_of(self, schema_section: dict, data: Any, reference: str, **kwargs: Any) -> None:
-        all_of = schema_section.pop("allOf")
-        self.test_schema_section(
-            schema_section={**schema_section, **combine_sub_schemas(all_of)},
-            data=data,
-            reference=f"{reference}.allOf",
-            **kwargs,
-        )
-
     def handle_one_of(self, schema_section: dict, data: Any, reference: str, **kwargs: Any):
         matches = 0
         for option in schema_section["oneOf"]:
@@ -174,12 +165,7 @@ class SchemaTester:
 
     def handle_any_of(self, schema_section: dict, data: Any, reference: str, **kwargs: Any):
         any_of: List[Dict[str, Any]] = schema_section.get("anyOf", [])
-        combined_sub_schemas = map(
-            lambda index: reduce(lambda x, y: combine_sub_schemas([x, y]), any_of[index:]),
-            range(len(any_of)),
-        )
-
-        for schema in [*any_of, *combined_sub_schemas]:
+        for schema in chain(any_of, lazy_combinations(any_of)):
             try:
                 self.test_schema_section(schema_section=schema, data=data, reference=f"{reference}.anyOf", **kwargs)
                 return
@@ -236,17 +222,9 @@ class SchemaTester:
                 f"Reference: {reference}\n\n"
                 f"Hint: Return a valid type, or document the value as nullable"
             )
-
+        schema_section = normalize_schema_section(schema_section)
         if "oneOf" in schema_section:
-            if schema_section["oneOf"] and all(item.get("enum") for item in schema_section["oneOf"]):
-                # handle the way drf-spectacular is doing enums
-                one_of = schema_section.pop("oneOf")
-                schema_section = {**schema_section, **merge_objects(one_of)}
-            else:
-                self.handle_one_of(schema_section=schema_section, data=data, reference=reference, **kwargs)
-                return
-        if "allOf" in schema_section:
-            self.handle_all_of(schema_section=schema_section, data=data, reference=reference, **kwargs)
+            self.handle_one_of(schema_section=schema_section, data=data, reference=reference, **kwargs)
             return
         if "anyOf" in schema_section:
             self.handle_any_of(schema_section=schema_section, data=data, reference=reference, **kwargs)
